<?php
class Author {
    private $conn;
    private $table_name = "authors";

    public $id;
    public $author;

    public function __construct($db) {
        $this->conn = $db;
    }

    // Read all authors
    public function read() {
        $query = "SELECT id, author FROM " . $this->table_name . " ORDER BY id ASC";
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        return $stmt;
    }

    // Read single author
    public function readSingle($id) {
        $query = "SELECT * FROM " . $this->table_name . " WHERE id = ? LIMIT 0,1";
    
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $id);
        $stmt->execute();
    
        return $stmt;
    }

    // Create a new author
    public function create() {
        $query = "INSERT INTO " . $this->table_name . " SET author=:author";
    
        $stmt = $this->conn->prepare($query);
    
        $this->author = htmlspecialchars(strip_tags($this->author));
    
        $stmt->bindParam(":author", $this->author);
    
        if ($stmt->execute()) {
            return $this->conn->lastInsertId();
        }
    
        return false;
    }

    // Update an author
    public function update() {
        $query = "UPDATE " . $this->table_name . " SET author = :author WHERE id = :id";
    
        $stmt = $this->conn->prepare($query);
    
        $this->author = htmlspecialchars(strip_tags($this->author));
        $this->id = htmlspecialchars(strip_tags($this->id));
    
        $stmt->bindParam(':author', $this->author);
        $stmt->bindParam(':id', $this->id);
    
        if ($stmt->execute()) {
            return true;
        }
    
        return false;
    }

    // Delete an author
    public function delete() {
        $query = "DELETE FROM " . $this->table_name . " WHERE id = :id";
    
        $stmt = $this->conn->prepare($query);
    
        $this->id = htmlspecialchars(strip_tags($this->id));
    
        $stmt->bindParam(':id', $this->id);
    
        if ($stmt->execute()) {
            return true;
        }
    
        return false;
    }

    public function find($id) {
        $query = "SELECT * FROM authors WHERE id = :id LIMIT 1";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $id);
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            return true;
        } else {
            return false;
        }
    }
}
