<?php
class Category {
    private $conn;
    private $table_name = "categories";

    public $id;
    public $category;

    public function __construct($db) {
        $this->conn = $db;
    }

    // Read all categories
    public function read() {
        $query = "SELECT id, category FROM " . $this->table_name . " ORDER BY id ASC";
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        return $stmt;
    }

    // Read a single category
    public function readSingle() {
        $query = "SELECT id, category FROM " . $this->table_name . " WHERE id = ? LIMIT 0,1";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);
        $stmt->execute();
    
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
    
        if ($row !== false) {
            // It's safe to access $row as an array
            $this->category = $row['category'];
        } else {
            // Handle the error or exit gracefully
            $this->category = null;
        }
    }

    // Create a new category
 public function create() {
    $query = "INSERT INTO " . $this->table_name . " SET category=:category";
    $stmt = $this->conn->prepare($query);

    $this->category = htmlspecialchars(strip_tags($this->category));

    $stmt->bindParam(":category", $this->category);

    if ($stmt->execute()) {
        $this->id = $this->conn->lastInsertId();
        return true;
    }

    return false;
}

    // Update an existing category
    public function update() {
        $query = "UPDATE " . $this->table_name . " SET category = :category WHERE id = :id";
        $stmt = $this->conn->prepare($query);
    
        $this->id = htmlspecialchars(strip_tags($this->id));
        $this->category = htmlspecialchars(strip_tags($this->category));
    
        $stmt->bindParam(':id', $this->id);
        $stmt->bindParam(':category', $this->category);
    
        if ($stmt->execute()) {
            return true;
        }
    
        return false;
    }

    // Delete a category
    public function delete() {
        $query = "DELETE FROM " . $this->table_name . " WHERE id = :id";
        $stmt = $this->conn->prepare($query);
    
        $this->id = htmlspecialchars(strip_tags($this->id));
    
        $stmt->bindParam(':id', $this->id);
    
        if ($stmt->execute()) {
            return true;
        }
    
        return false;
    }

    public function find($id) {
        $query = "SELECT * FROM categories WHERE id = :id LIMIT 1";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $id);
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            return true;
        } else {
            return false;
        }
    }
}
